@@ -2,6 +2,7 @@ from typing import List, Optional, Dict, Union
 from importlib.metadata import version
 
 import requests
+import logging
 
 from aleph_alpha_client.image import ImagePrompt
 
@@ -54,9 +55,8 @@ class AlephAlphaClient:
         # check server version
         expect_release = "1"
         version = self.get_version()
-        assert version.startswith(
-            expect_release
-        ), f"Expected API version {expect_release}.x.x, got {version}. Please update client."
+        if version.startswith(expect_release):
+            logging.warning(f"Expected API version {expect_release}.x.x, got {version}. Please update client.")
 
         assert token is not None or (email is not None and password is not None)
         self.token = token or self.get_token(email, password)
